**Example 1: 发布配置**



Input: 

```
tccli tsf ReleaseConfig --cli-unfold-argument  \
    --ConfigId dcfg-zvw6kxa8 \
    --GroupId group-nalqbgvq
```

Output: 
```
{
    "Response": {
        "RequestId": "36ccafba-c8ab-4d15-a4f1-4cfd2070d1d3",
        "Result": true
    }
}
```

